# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qm/pb/job_results.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='qm/pb/job_results.proto',
  package='qm.grpc.results_analyser',
  syntax='proto3',
  serialized_options=b'\n\017qm.grpc.resultsB\017JobResultsProtoP\001\242\002\003HLW',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17qm/pb/job_results.proto\x12\x18qm.grpc.results_analyser\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cqm/pb/general_messages.proto\x1a\x1cgoogle/protobuf/struct.proto\"*\n\x19GetProgramMetadataRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\x8c\x01\n\x1aGetProgramMetadataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12N\n\x15programStreamMetadata\x18\x03 \x01(\x0b\x32/.qm.grpc.results_analyser.ProgramStreamMetadata\"\xb9\x01\n\x15ProgramStreamMetadata\x12@\n\x0estreamMetadata\x18\x01 \x03(\x0b\x32(.qm.grpc.results_analyser.StreamMetadata\x12^\n\x1dstreamMetadataExtractionError\x18\x02 \x03(\x0b\x32\x37.qm.grpc.results_analyser.StreamMetadataExtractionError\"d\n\x0eStreamMetadata\x12\x12\n\nstreamName\x18\x01 \x01(\t\x12>\n\riterationData\x18\x02 \x03(\x0b\x32\'.qm.grpc.results_analyser.IterationData\"@\n\x1dStreamMetadataExtractionError\x12\x10\n\x08location\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\xeb\x05\n\rIterationData\x12\x1d\n\x15iterationVariableName\x18\x01 \x01(\t\x12\x66\n\x19\x66orEachIntIterationValues\x18\x02 \x01(\x0b\x32\x41.qm.grpc.results_analyser.IterationData.ForEachIntIterationValuesH\x00\x12^\n\x15\x66orIntIterationValues\x18\x03 \x01(\x0b\x32=.qm.grpc.results_analyser.IterationData.ForIntIterationValuesH\x00\x12l\n\x1c\x66orEachDoubleIterationValues\x18\x04 \x01(\x0b\x32\x44.qm.grpc.results_analyser.IterationData.ForEachDoubleIterationValuesH\x00\x12\x64\n\x18\x66orDoubleIterationValues\x18\x05 \x01(\x0b\x32@.qm.grpc.results_analyser.IterationData.ForDoubleIterationValuesH\x00\x1a+\n\x19\x46orEachIntIterationValues\x12\x0e\n\x06values\x18\x01 \x03(\x05\x1aU\n\x15\x46orIntIterationValues\x12\x12\n\nstartValue\x18\x01 \x01(\x05\x12\x0c\n\x04step\x18\x02 \x01(\x05\x12\x1a\n\x12numberOfIterations\x18\x03 \x01(\x05\x1a.\n\x1c\x46orEachDoubleIterationValues\x12\x0e\n\x06values\x18\x01 \x03(\x01\x1aX\n\x18\x46orDoubleIterationValues\x12\x12\n\nstartValue\x18\x01 \x01(\x01\x12\x0c\n\x04step\x18\x02 \x01(\x01\x12\x1a\n\x12numberOfIterations\x18\x03 \x01(\x05\x42\x11\n\x0fiterationValues\"*\n\x19GetJobResultSchemaRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\xc9\x01\n\x1aGetJobResultSchemaResponse\x12H\n\x05items\x18\x01 \x03(\x0b\x32\x39.qm.grpc.results_analyser.GetJobResultSchemaResponse.Item\x1a\x61\n\x04Item\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bsimpleDType\x18\x02 \x01(\t\x12\x10\n\x08isSingle\x18\x03 \x01(\x08\x12\x15\n\rexpectedCount\x18\x04 \x01(\x05\x12\r\n\x05shape\x18\x05 \x03(\x05\"#\n\x12GetJobStateRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"H\n\x13GetJobStateResponse\x12\x0c\n\x04\x64one\x18\x01 \x01(\x08\x12\x0e\n\x06\x63losed\x18\x02 \x01(\x08\x12\x13\n\x0bhasDataloss\x18\x03 \x01(\x08\"W\n\x1eGetJobNamedResultHeaderRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\x12\x12\n\nflatFormat\x18\x03 \x01(\x08\"\xde\x01\n\x1fGetJobNamedResultHeaderResponse\x12\x10\n\x08isSingle\x18\x01 \x01(\x08\x12\x12\n\ncountSoFar\x18\x02 \x01(\x05\x12\x13\n\x0bsimpleDType\x18\x03 \x01(\t\x12\x10\n\x04\x64one\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\x12\n\x06\x63losed\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x13\n\x0bhasDataloss\x18\x06 \x01(\x08\x12\r\n\x05shape\x18\x07 \x03(\x05\x12\x36\n\x12hasExecutionErrors\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x91\x01\n\x18GetJobNamedResultRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\x12\x12\n\x06offset\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\r\n\x05limit\x18\x04 \x01(\x05\x12/\n\nlongOffset\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"?\n\x19GetJobNamedResultResponse\x12\x14\n\x0c\x63ountOfItems\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"$\n\x13GetJobErrorsRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\'\n\x16GetJobDebugDataRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"6\n\x17GetJobDebugDataResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05jobId\x18\x02 \x01(\t\"\xa9\x02\n\x14GetJobErrorsResponse\x12\x44\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x34.qm.grpc.results_analyser.GetJobErrorsResponse.Error\x12\r\n\x05jobId\x18\x02 \x01(\t\x1a\x89\x01\n\x05\x45rror\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12\\\n\rerrorSeverity\x18\x02 \x01(\x0e\x32\x45.qm.grpc.results_analyser.GetJobErrorsResponse.ExecutionErrorSeverity\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\x16\x45xecutionErrorSeverity\x12\t\n\x05\x45RROR\x10\x00\x12\x0b\n\x07WARNING\x10\x01\"\\\n\x1aPullAnalysedResultsRequest\x12\x13\n\x0bjobFilePath\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x12\x17\n\x0f\x63ontainsVersion\x18\x03 \x01(\x08\"\xe8\x01\n\x17\x41nalysedResultsResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12;\n\nicpResults\x18\x0b \x03(\x0b\x32\'.qm.grpc.results_analyser.IcpResultData\x12\x41\n\rstreamResults\x18\x0c \x03(\x0b\x32*.qm.grpc.results_analyser.StreamResultData\x12\x36\n\x06\x65rrors\x18\r \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessageJ\x04\x08\x02\x10\x0b\"<\n\x17PullResultOutputRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\"\xca\x04\n\x18PullResultOutputResponse\x12G\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x37.qm.grpc.results_analyser.PullResultOutputResponse.DataH\x00\x12K\n\x06header\x18\x02 \x01(\x0b\x32\x39.qm.grpc.results_analyser.PullResultOutputResponse.HeaderH\x00\x12\x45\n\x03npz\x18\x03 \x01(\x0b\x32\x36.qm.grpc.results_analyser.PullResultOutputResponse.NpzH\x00\x12\x45\n\x03npy\x18\x04 \x01(\x0b\x32\x36.qm.grpc.results_analyser.PullResultOutputResponse.NpyH\x00\x1a\x87\x01\n\x06Header\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61taLoss\x18\x03 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x04 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\x12\x0e\n\x06single\x18\x05 \x01(\x08\x1a/\n\x04\x44\x61ta\x12\'\n\x07results\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\x1a\x12\n\x03Npz\x12\x0b\n\x03npz\x18\x01 \x01(\x0c\x1a/\n\x03Npy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03npy\x18\x02 \x01(\x0c\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x42\n\n\x08response\"\x1d\n\rBinaryWrapper\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x0c\"U\n\x15PullFileResultRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x12\x0f\n\x05\x61sNpz\x18\x04 \x01(\x08H\x00\x42\n\n\x08\x66ileType\"\xaa\x01\n\x12\x46ileResultResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x16\n\x0e\x63ontrollerName\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\r\n\x03npz\x18\x04 \x01(\x0cH\x00\x12\x0f\n\x07version\x18\n \x01(\t\x12\x36\n\x06\x65rrors\x18\x0b \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessageB\x06\n\x04\x66ile\"x\n\x1bPullSimulatorSamplesRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x15\n\rincludeAnalog\x18\x02 \x01(\x08\x12\x16\n\x0eincludeDigital\x18\x03 \x01(\x08\x12\x0f\n\x05\x61sNpz\x18\x04 \x01(\x08H\x00\x42\n\n\x08\x66ileType\"\xa4\x02\n\x18SimulatorSamplesResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\n\n\x02ok\x18\x05 \x01(\x08\x12K\n\x06header\x18\x06 \x01(\x0b\x32\x39.qm.grpc.results_analyser.SimulatorSamplesResponse.HeaderH\x00\x12G\n\x04\x64\x61ta\x18\x07 \x01(\x0b\x32\x37.qm.grpc.results_analyser.SimulatorSamplesResponse.DataH\x00\x1a\x33\n\x06Header\x12\x13\n\x0bsimpleDType\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountOfItems\x18\x02 \x01(\x05\x1a\x14\n\x04\x44\x61ta\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\x0c\x42\x06\n\x04\x62odyJ\x04\x08\x02\x10\x05\"\x93\x01\n\rIcpResultData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x10\n\x08\x64\x61taLoss\x18\x03 \x01(\x08\x12\x12\n\x08intValue\x18\x0b \x01(\x05H\x00\x12\x15\n\x0b\x64oubleValue\x18\x0c \x01(\x01H\x00\x12\x16\n\x0c\x62ooleanValue\x18\r \x01(\x08H\x00\x42\x06\n\x04\x64\x61taJ\x04\x08\x04\x10\x0b\"\x8a\x01\n\x10StreamResultData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x10\n\x08\x64\x61taLoss\x18\x03 \x01(\x08\x12\x17\n\x0fmultipleSources\x18\x04 \x01(\x08\x12\x16\n\x0e\x64\x61taSourceName\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x0b \x01(\x03J\x04\x08\x06\x10\x0b\x32\x8c\x07\n\x11JobResultsService\x12\x81\x01\n\x12GetJobResultSchema\x12\x33.qm.grpc.results_analyser.GetJobResultSchemaRequest\x1a\x34.qm.grpc.results_analyser.GetJobResultSchemaResponse\"\x00\x12l\n\x0bGetJobState\x12,.qm.grpc.results_analyser.GetJobStateRequest\x1a-.qm.grpc.results_analyser.GetJobStateResponse\"\x00\x12\x90\x01\n\x17GetJobNamedResultHeader\x12\x38.qm.grpc.results_analyser.GetJobNamedResultHeaderRequest\x1a\x39.qm.grpc.results_analyser.GetJobNamedResultHeaderResponse\"\x00\x12\x80\x01\n\x11GetJobNamedResult\x12\x32.qm.grpc.results_analyser.GetJobNamedResultRequest\x1a\x33.qm.grpc.results_analyser.GetJobNamedResultResponse\"\x00\x30\x01\x12z\n\x0fGetJobDebugData\x12\x30.qm.grpc.results_analyser.GetJobDebugDataRequest\x1a\x31.qm.grpc.results_analyser.GetJobDebugDataResponse\"\x00\x30\x01\x12o\n\x0cGetJobErrors\x12-.qm.grpc.results_analyser.GetJobErrorsRequest\x1a..qm.grpc.results_analyser.GetJobErrorsResponse\"\x00\x12\x81\x01\n\x12GetProgramMetadata\x12\x33.qm.grpc.results_analyser.GetProgramMetadataRequest\x1a\x34.qm.grpc.results_analyser.GetProgramMetadataResponse\"\x00\x42*\n\x0fqm.grpc.resultsB\x0fJobResultsProtoP\x01\xa2\x02\x03HLWb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,qm_dot_pb_dot_general__messages__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])



_GETJOBERRORSRESPONSE_EXECUTIONERRORSEVERITY = _descriptor.EnumDescriptor(
  name='ExecutionErrorSeverity',
  full_name='qm.grpc.results_analyser.GetJobErrorsResponse.ExecutionErrorSeverity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2709,
  serialized_end=2757,
)
_sym_db.RegisterEnumDescriptor(_GETJOBERRORSRESPONSE_EXECUTIONERRORSEVERITY)


_GETPROGRAMMETADATAREQUEST = _descriptor.Descriptor(
  name='GetProgramMetadataRequest',
  full_name='qm.grpc.results_analyser.GetProgramMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetProgramMetadataRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=187,
)


_GETPROGRAMMETADATARESPONSE = _descriptor.Descriptor(
  name='GetProgramMetadataResponse',
  full_name='qm.grpc.results_analyser.GetProgramMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='qm.grpc.results_analyser.GetProgramMetadataResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetProgramMetadataResponse.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='programStreamMetadata', full_name='qm.grpc.results_analyser.GetProgramMetadataResponse.programStreamMetadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=330,
)


_PROGRAMSTREAMMETADATA = _descriptor.Descriptor(
  name='ProgramStreamMetadata',
  full_name='qm.grpc.results_analyser.ProgramStreamMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamMetadata', full_name='qm.grpc.results_analyser.ProgramStreamMetadata.streamMetadata', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamMetadataExtractionError', full_name='qm.grpc.results_analyser.ProgramStreamMetadata.streamMetadataExtractionError', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=518,
)


_STREAMMETADATA = _descriptor.Descriptor(
  name='StreamMetadata',
  full_name='qm.grpc.results_analyser.StreamMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamName', full_name='qm.grpc.results_analyser.StreamMetadata.streamName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iterationData', full_name='qm.grpc.results_analyser.StreamMetadata.iterationData', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=620,
)


_STREAMMETADATAEXTRACTIONERROR = _descriptor.Descriptor(
  name='StreamMetadataExtractionError',
  full_name='qm.grpc.results_analyser.StreamMetadataExtractionError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='qm.grpc.results_analyser.StreamMetadataExtractionError.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='qm.grpc.results_analyser.StreamMetadataExtractionError.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=686,
)


_ITERATIONDATA_FOREACHINTITERATIONVALUES = _descriptor.Descriptor(
  name='ForEachIntIterationValues',
  full_name='qm.grpc.results_analyser.IterationData.ForEachIntIterationValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='qm.grpc.results_analyser.IterationData.ForEachIntIterationValues.values', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1149,
  serialized_end=1192,
)

_ITERATIONDATA_FORINTITERATIONVALUES = _descriptor.Descriptor(
  name='ForIntIterationValues',
  full_name='qm.grpc.results_analyser.IterationData.ForIntIterationValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startValue', full_name='qm.grpc.results_analyser.IterationData.ForIntIterationValues.startValue', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='qm.grpc.results_analyser.IterationData.ForIntIterationValues.step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numberOfIterations', full_name='qm.grpc.results_analyser.IterationData.ForIntIterationValues.numberOfIterations', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1279,
)

_ITERATIONDATA_FOREACHDOUBLEITERATIONVALUES = _descriptor.Descriptor(
  name='ForEachDoubleIterationValues',
  full_name='qm.grpc.results_analyser.IterationData.ForEachDoubleIterationValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='qm.grpc.results_analyser.IterationData.ForEachDoubleIterationValues.values', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1327,
)

_ITERATIONDATA_FORDOUBLEITERATIONVALUES = _descriptor.Descriptor(
  name='ForDoubleIterationValues',
  full_name='qm.grpc.results_analyser.IterationData.ForDoubleIterationValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startValue', full_name='qm.grpc.results_analyser.IterationData.ForDoubleIterationValues.startValue', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='qm.grpc.results_analyser.IterationData.ForDoubleIterationValues.step', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numberOfIterations', full_name='qm.grpc.results_analyser.IterationData.ForDoubleIterationValues.numberOfIterations', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1329,
  serialized_end=1417,
)

_ITERATIONDATA = _descriptor.Descriptor(
  name='IterationData',
  full_name='qm.grpc.results_analyser.IterationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iterationVariableName', full_name='qm.grpc.results_analyser.IterationData.iterationVariableName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forEachIntIterationValues', full_name='qm.grpc.results_analyser.IterationData.forEachIntIterationValues', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forIntIterationValues', full_name='qm.grpc.results_analyser.IterationData.forIntIterationValues', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forEachDoubleIterationValues', full_name='qm.grpc.results_analyser.IterationData.forEachDoubleIterationValues', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forDoubleIterationValues', full_name='qm.grpc.results_analyser.IterationData.forDoubleIterationValues', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ITERATIONDATA_FOREACHINTITERATIONVALUES, _ITERATIONDATA_FORINTITERATIONVALUES, _ITERATIONDATA_FOREACHDOUBLEITERATIONVALUES, _ITERATIONDATA_FORDOUBLEITERATIONVALUES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='iterationValues', full_name='qm.grpc.results_analyser.IterationData.iterationValues',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=689,
  serialized_end=1436,
)


_GETJOBRESULTSCHEMAREQUEST = _descriptor.Descriptor(
  name='GetJobResultSchemaRequest',
  full_name='qm.grpc.results_analyser.GetJobResultSchemaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobResultSchemaRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1480,
)


_GETJOBRESULTSCHEMARESPONSE_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse.Item.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simpleDType', full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse.Item.simpleDType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isSingle', full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse.Item.isSingle', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expectedCount', full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse.Item.expectedCount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse.Item.shape', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1684,
)

_GETJOBRESULTSCHEMARESPONSE = _descriptor.Descriptor(
  name='GetJobResultSchemaResponse',
  full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='qm.grpc.results_analyser.GetJobResultSchemaResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETJOBRESULTSCHEMARESPONSE_ITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1483,
  serialized_end=1684,
)


_GETJOBSTATEREQUEST = _descriptor.Descriptor(
  name='GetJobStateRequest',
  full_name='qm.grpc.results_analyser.GetJobStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobStateRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1686,
  serialized_end=1721,
)


_GETJOBSTATERESPONSE = _descriptor.Descriptor(
  name='GetJobStateResponse',
  full_name='qm.grpc.results_analyser.GetJobStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='done', full_name='qm.grpc.results_analyser.GetJobStateResponse.done', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closed', full_name='qm.grpc.results_analyser.GetJobStateResponse.closed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hasDataloss', full_name='qm.grpc.results_analyser.GetJobStateResponse.hasDataloss', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1723,
  serialized_end=1795,
)


_GETJOBNAMEDRESULTHEADERREQUEST = _descriptor.Descriptor(
  name='GetJobNamedResultHeaderRequest',
  full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputName', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderRequest.outputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatFormat', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderRequest.flatFormat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=1884,
)


_GETJOBNAMEDRESULTHEADERRESPONSE = _descriptor.Descriptor(
  name='GetJobNamedResultHeaderResponse',
  full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSingle', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.isSingle', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='countSoFar', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.countSoFar', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simpleDType', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.simpleDType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.done', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closed', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.closed', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hasDataloss', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.hasDataloss', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.shape', index=6,
      number=7, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hasExecutionErrors', full_name='qm.grpc.results_analyser.GetJobNamedResultHeaderResponse.hasExecutionErrors', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1887,
  serialized_end=2109,
)


_GETJOBNAMEDRESULTREQUEST = _descriptor.Descriptor(
  name='GetJobNamedResultRequest',
  full_name='qm.grpc.results_analyser.GetJobNamedResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobNamedResultRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputName', full_name='qm.grpc.results_analyser.GetJobNamedResultRequest.outputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='qm.grpc.results_analyser.GetJobNamedResultRequest.offset', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='qm.grpc.results_analyser.GetJobNamedResultRequest.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longOffset', full_name='qm.grpc.results_analyser.GetJobNamedResultRequest.longOffset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2112,
  serialized_end=2257,
)


_GETJOBNAMEDRESULTRESPONSE = _descriptor.Descriptor(
  name='GetJobNamedResultResponse',
  full_name='qm.grpc.results_analyser.GetJobNamedResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='countOfItems', full_name='qm.grpc.results_analyser.GetJobNamedResultResponse.countOfItems', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.results_analyser.GetJobNamedResultResponse.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2322,
)


_GETJOBERRORSREQUEST = _descriptor.Descriptor(
  name='GetJobErrorsRequest',
  full_name='qm.grpc.results_analyser.GetJobErrorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobErrorsRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2324,
  serialized_end=2360,
)


_GETJOBDEBUGDATAREQUEST = _descriptor.Descriptor(
  name='GetJobDebugDataRequest',
  full_name='qm.grpc.results_analyser.GetJobDebugDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobDebugDataRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2362,
  serialized_end=2401,
)


_GETJOBDEBUGDATARESPONSE = _descriptor.Descriptor(
  name='GetJobDebugDataResponse',
  full_name='qm.grpc.results_analyser.GetJobDebugDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.results_analyser.GetJobDebugDataResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobDebugDataResponse.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2403,
  serialized_end=2457,
)


_GETJOBERRORSRESPONSE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='qm.grpc.results_analyser.GetJobErrorsResponse.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errorCode', full_name='qm.grpc.results_analyser.GetJobErrorsResponse.Error.errorCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorSeverity', full_name='qm.grpc.results_analyser.GetJobErrorsResponse.Error.errorSeverity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='qm.grpc.results_analyser.GetJobErrorsResponse.Error.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2570,
  serialized_end=2707,
)

_GETJOBERRORSRESPONSE = _descriptor.Descriptor(
  name='GetJobErrorsResponse',
  full_name='qm.grpc.results_analyser.GetJobErrorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.results_analyser.GetJobErrorsResponse.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.GetJobErrorsResponse.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETJOBERRORSRESPONSE_ERROR, ],
  enum_types=[
    _GETJOBERRORSRESPONSE_EXECUTIONERRORSEVERITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2460,
  serialized_end=2757,
)


_PULLANALYSEDRESULTSREQUEST = _descriptor.Descriptor(
  name='PullAnalysedResultsRequest',
  full_name='qm.grpc.results_analyser.PullAnalysedResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobFilePath', full_name='qm.grpc.results_analyser.PullAnalysedResultsRequest.jobFilePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='qm.grpc.results_analyser.PullAnalysedResultsRequest.metadata', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='containsVersion', full_name='qm.grpc.results_analyser.PullAnalysedResultsRequest.containsVersion', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2759,
  serialized_end=2851,
)


_ANALYSEDRESULTSRESPONSE = _descriptor.Descriptor(
  name='AnalysedResultsResponse',
  full_name='qm.grpc.results_analyser.AnalysedResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='qm.grpc.results_analyser.AnalysedResultsResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icpResults', full_name='qm.grpc.results_analyser.AnalysedResultsResponse.icpResults', index=1,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamResults', full_name='qm.grpc.results_analyser.AnalysedResultsResponse.streamResults', index=2,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.results_analyser.AnalysedResultsResponse.errors', index=3,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2854,
  serialized_end=3086,
)


_PULLRESULTOUTPUTREQUEST = _descriptor.Descriptor(
  name='PullResultOutputRequest',
  full_name='qm.grpc.results_analyser.PullResultOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.PullResultOutputRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputName', full_name='qm.grpc.results_analyser.PullResultOutputRequest.outputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3088,
  serialized_end=3148,
)


_PULLRESULTOUTPUTRESPONSE_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='qm.grpc.results_analyser.PullResultOutputResponse.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Header.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputName', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Header.outputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataLoss', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Header.dataLoss', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Header.errors', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Header.single', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3472,
  serialized_end=3607,
)

_PULLRESULTOUTPUTRESPONSE_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='qm.grpc.results_analyser.PullResultOutputResponse.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Data.results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3609,
  serialized_end=3656,
)

_PULLRESULTOUTPUTRESPONSE_NPZ = _descriptor.Descriptor(
  name='Npz',
  full_name='qm.grpc.results_analyser.PullResultOutputResponse.Npz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='npz', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Npz.npz', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3658,
  serialized_end=3676,
)

_PULLRESULTOUTPUTRESPONSE_NPY = _descriptor.Descriptor(
  name='Npy',
  full_name='qm.grpc.results_analyser.PullResultOutputResponse.Npy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Npy.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='npy', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Npy.npy', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='qm.grpc.results_analyser.PullResultOutputResponse.Npy.count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3678,
  serialized_end=3725,
)

_PULLRESULTOUTPUTRESPONSE = _descriptor.Descriptor(
  name='PullResultOutputResponse',
  full_name='qm.grpc.results_analyser.PullResultOutputResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.results_analyser.PullResultOutputResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='qm.grpc.results_analyser.PullResultOutputResponse.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='npz', full_name='qm.grpc.results_analyser.PullResultOutputResponse.npz', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='npy', full_name='qm.grpc.results_analyser.PullResultOutputResponse.npy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PULLRESULTOUTPUTRESPONSE_HEADER, _PULLRESULTOUTPUTRESPONSE_DATA, _PULLRESULTOUTPUTRESPONSE_NPZ, _PULLRESULTOUTPUTRESPONSE_NPY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='qm.grpc.results_analyser.PullResultOutputResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3151,
  serialized_end=3737,
)


_BINARYWRAPPER = _descriptor.Descriptor(
  name='BinaryWrapper',
  full_name='qm.grpc.results_analyser.BinaryWrapper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.results_analyser.BinaryWrapper.data', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3739,
  serialized_end=3768,
)


_PULLFILERESULTREQUEST = _descriptor.Descriptor(
  name='PullFileResultRequest',
  full_name='qm.grpc.results_analyser.PullFileResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.PullFileResultRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='qm.grpc.results_analyser.PullFileResultRequest.metadata', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asNpz', full_name='qm.grpc.results_analyser.PullFileResultRequest.asNpz', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='fileType', full_name='qm.grpc.results_analyser.PullFileResultRequest.fileType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3770,
  serialized_end=3855,
)


_FILERESULTRESPONSE = _descriptor.Descriptor(
  name='FileResultResponse',
  full_name='qm.grpc.results_analyser.FileResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.FileResultResponse.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerName', full_name='qm.grpc.results_analyser.FileResultResponse.controllerName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='qm.grpc.results_analyser.FileResultResponse.group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='npz', full_name='qm.grpc.results_analyser.FileResultResponse.npz', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='qm.grpc.results_analyser.FileResultResponse.version', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.results_analyser.FileResultResponse.errors', index=5,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='file', full_name='qm.grpc.results_analyser.FileResultResponse.file',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3858,
  serialized_end=4028,
)


_PULLSIMULATORSAMPLESREQUEST = _descriptor.Descriptor(
  name='PullSimulatorSamplesRequest',
  full_name='qm.grpc.results_analyser.PullSimulatorSamplesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.PullSimulatorSamplesRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeAnalog', full_name='qm.grpc.results_analyser.PullSimulatorSamplesRequest.includeAnalog', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeDigital', full_name='qm.grpc.results_analyser.PullSimulatorSamplesRequest.includeDigital', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asNpz', full_name='qm.grpc.results_analyser.PullSimulatorSamplesRequest.asNpz', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='fileType', full_name='qm.grpc.results_analyser.PullSimulatorSamplesRequest.fileType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4030,
  serialized_end=4150,
)


_SIMULATORSAMPLESRESPONSE_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='simpleDType', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.Header.simpleDType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='countOfItems', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.Header.countOfItems', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4358,
  serialized_end=4409,
)

_SIMULATORSAMPLESRESPONSE_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.Data.data', index=0,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4411,
  serialized_end=4431,
)

_SIMULATORSAMPLESRESPONSE = _descriptor.Descriptor(
  name='SimulatorSamplesResponse',
  full_name='qm.grpc.results_analyser.SimulatorSamplesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.ok', index=1,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.header', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.data', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SIMULATORSAMPLESRESPONSE_HEADER, _SIMULATORSAMPLESRESPONSE_DATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='qm.grpc.results_analyser.SimulatorSamplesResponse.body',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4153,
  serialized_end=4445,
)


_ICPRESULTDATA = _descriptor.Descriptor(
  name='IcpResultData',
  full_name='qm.grpc.results_analyser.IcpResultData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.results_analyser.IcpResultData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='qm.grpc.results_analyser.IcpResultData.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataLoss', full_name='qm.grpc.results_analyser.IcpResultData.dataLoss', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intValue', full_name='qm.grpc.results_analyser.IcpResultData.intValue', index=3,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='qm.grpc.results_analyser.IcpResultData.doubleValue', index=4,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='booleanValue', full_name='qm.grpc.results_analyser.IcpResultData.booleanValue', index=5,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='qm.grpc.results_analyser.IcpResultData.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4448,
  serialized_end=4595,
)


_STREAMRESULTDATA = _descriptor.Descriptor(
  name='StreamResultData',
  full_name='qm.grpc.results_analyser.StreamResultData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.results_analyser.StreamResultData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='qm.grpc.results_analyser.StreamResultData.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataLoss', full_name='qm.grpc.results_analyser.StreamResultData.dataLoss', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multipleSources', full_name='qm.grpc.results_analyser.StreamResultData.multipleSources', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataSourceName', full_name='qm.grpc.results_analyser.StreamResultData.dataSourceName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='qm.grpc.results_analyser.StreamResultData.data', index=5,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4598,
  serialized_end=4736,
)

_GETPROGRAMMETADATARESPONSE.fields_by_name['programStreamMetadata'].message_type = _PROGRAMSTREAMMETADATA
_PROGRAMSTREAMMETADATA.fields_by_name['streamMetadata'].message_type = _STREAMMETADATA
_PROGRAMSTREAMMETADATA.fields_by_name['streamMetadataExtractionError'].message_type = _STREAMMETADATAEXTRACTIONERROR
_STREAMMETADATA.fields_by_name['iterationData'].message_type = _ITERATIONDATA
_ITERATIONDATA_FOREACHINTITERATIONVALUES.containing_type = _ITERATIONDATA
_ITERATIONDATA_FORINTITERATIONVALUES.containing_type = _ITERATIONDATA
_ITERATIONDATA_FOREACHDOUBLEITERATIONVALUES.containing_type = _ITERATIONDATA
_ITERATIONDATA_FORDOUBLEITERATIONVALUES.containing_type = _ITERATIONDATA
_ITERATIONDATA.fields_by_name['forEachIntIterationValues'].message_type = _ITERATIONDATA_FOREACHINTITERATIONVALUES
_ITERATIONDATA.fields_by_name['forIntIterationValues'].message_type = _ITERATIONDATA_FORINTITERATIONVALUES
_ITERATIONDATA.fields_by_name['forEachDoubleIterationValues'].message_type = _ITERATIONDATA_FOREACHDOUBLEITERATIONVALUES
_ITERATIONDATA.fields_by_name['forDoubleIterationValues'].message_type = _ITERATIONDATA_FORDOUBLEITERATIONVALUES
_ITERATIONDATA.oneofs_by_name['iterationValues'].fields.append(
  _ITERATIONDATA.fields_by_name['forEachIntIterationValues'])
_ITERATIONDATA.fields_by_name['forEachIntIterationValues'].containing_oneof = _ITERATIONDATA.oneofs_by_name['iterationValues']
_ITERATIONDATA.oneofs_by_name['iterationValues'].fields.append(
  _ITERATIONDATA.fields_by_name['forIntIterationValues'])
_ITERATIONDATA.fields_by_name['forIntIterationValues'].containing_oneof = _ITERATIONDATA.oneofs_by_name['iterationValues']
_ITERATIONDATA.oneofs_by_name['iterationValues'].fields.append(
  _ITERATIONDATA.fields_by_name['forEachDoubleIterationValues'])
_ITERATIONDATA.fields_by_name['forEachDoubleIterationValues'].containing_oneof = _ITERATIONDATA.oneofs_by_name['iterationValues']
_ITERATIONDATA.oneofs_by_name['iterationValues'].fields.append(
  _ITERATIONDATA.fields_by_name['forDoubleIterationValues'])
_ITERATIONDATA.fields_by_name['forDoubleIterationValues'].containing_oneof = _ITERATIONDATA.oneofs_by_name['iterationValues']
_GETJOBRESULTSCHEMARESPONSE_ITEM.containing_type = _GETJOBRESULTSCHEMARESPONSE
_GETJOBRESULTSCHEMARESPONSE.fields_by_name['items'].message_type = _GETJOBRESULTSCHEMARESPONSE_ITEM
_GETJOBNAMEDRESULTHEADERRESPONSE.fields_by_name['hasExecutionErrors'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GETJOBNAMEDRESULTREQUEST.fields_by_name['longOffset'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GETJOBERRORSRESPONSE_ERROR.fields_by_name['errorSeverity'].enum_type = _GETJOBERRORSRESPONSE_EXECUTIONERRORSEVERITY
_GETJOBERRORSRESPONSE_ERROR.containing_type = _GETJOBERRORSRESPONSE
_GETJOBERRORSRESPONSE.fields_by_name['errors'].message_type = _GETJOBERRORSRESPONSE_ERROR
_GETJOBERRORSRESPONSE_EXECUTIONERRORSEVERITY.containing_type = _GETJOBERRORSRESPONSE
_ANALYSEDRESULTSRESPONSE.fields_by_name['icpResults'].message_type = _ICPRESULTDATA
_ANALYSEDRESULTSRESPONSE.fields_by_name['streamResults'].message_type = _STREAMRESULTDATA
_ANALYSEDRESULTSRESPONSE.fields_by_name['errors'].message_type = qm_dot_pb_dot_general__messages__pb2._ERRORMESSAGE
_PULLRESULTOUTPUTRESPONSE_HEADER.fields_by_name['errors'].message_type = qm_dot_pb_dot_general__messages__pb2._ERRORMESSAGE
_PULLRESULTOUTPUTRESPONSE_HEADER.containing_type = _PULLRESULTOUTPUTRESPONSE
_PULLRESULTOUTPUTRESPONSE_DATA.fields_by_name['results'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_PULLRESULTOUTPUTRESPONSE_DATA.containing_type = _PULLRESULTOUTPUTRESPONSE
_PULLRESULTOUTPUTRESPONSE_NPZ.containing_type = _PULLRESULTOUTPUTRESPONSE
_PULLRESULTOUTPUTRESPONSE_NPY.containing_type = _PULLRESULTOUTPUTRESPONSE
_PULLRESULTOUTPUTRESPONSE.fields_by_name['data'].message_type = _PULLRESULTOUTPUTRESPONSE_DATA
_PULLRESULTOUTPUTRESPONSE.fields_by_name['header'].message_type = _PULLRESULTOUTPUTRESPONSE_HEADER
_PULLRESULTOUTPUTRESPONSE.fields_by_name['npz'].message_type = _PULLRESULTOUTPUTRESPONSE_NPZ
_PULLRESULTOUTPUTRESPONSE.fields_by_name['npy'].message_type = _PULLRESULTOUTPUTRESPONSE_NPY
_PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response'].fields.append(
  _PULLRESULTOUTPUTRESPONSE.fields_by_name['data'])
_PULLRESULTOUTPUTRESPONSE.fields_by_name['data'].containing_oneof = _PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response']
_PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response'].fields.append(
  _PULLRESULTOUTPUTRESPONSE.fields_by_name['header'])
_PULLRESULTOUTPUTRESPONSE.fields_by_name['header'].containing_oneof = _PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response']
_PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response'].fields.append(
  _PULLRESULTOUTPUTRESPONSE.fields_by_name['npz'])
_PULLRESULTOUTPUTRESPONSE.fields_by_name['npz'].containing_oneof = _PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response']
_PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response'].fields.append(
  _PULLRESULTOUTPUTRESPONSE.fields_by_name['npy'])
_PULLRESULTOUTPUTRESPONSE.fields_by_name['npy'].containing_oneof = _PULLRESULTOUTPUTRESPONSE.oneofs_by_name['response']
_PULLFILERESULTREQUEST.oneofs_by_name['fileType'].fields.append(
  _PULLFILERESULTREQUEST.fields_by_name['asNpz'])
_PULLFILERESULTREQUEST.fields_by_name['asNpz'].containing_oneof = _PULLFILERESULTREQUEST.oneofs_by_name['fileType']
_FILERESULTRESPONSE.fields_by_name['errors'].message_type = qm_dot_pb_dot_general__messages__pb2._ERRORMESSAGE
_FILERESULTRESPONSE.oneofs_by_name['file'].fields.append(
  _FILERESULTRESPONSE.fields_by_name['npz'])
_FILERESULTRESPONSE.fields_by_name['npz'].containing_oneof = _FILERESULTRESPONSE.oneofs_by_name['file']
_PULLSIMULATORSAMPLESREQUEST.oneofs_by_name['fileType'].fields.append(
  _PULLSIMULATORSAMPLESREQUEST.fields_by_name['asNpz'])
_PULLSIMULATORSAMPLESREQUEST.fields_by_name['asNpz'].containing_oneof = _PULLSIMULATORSAMPLESREQUEST.oneofs_by_name['fileType']
_SIMULATORSAMPLESRESPONSE_HEADER.containing_type = _SIMULATORSAMPLESRESPONSE
_SIMULATORSAMPLESRESPONSE_DATA.containing_type = _SIMULATORSAMPLESRESPONSE
_SIMULATORSAMPLESRESPONSE.fields_by_name['header'].message_type = _SIMULATORSAMPLESRESPONSE_HEADER
_SIMULATORSAMPLESRESPONSE.fields_by_name['data'].message_type = _SIMULATORSAMPLESRESPONSE_DATA
_SIMULATORSAMPLESRESPONSE.oneofs_by_name['body'].fields.append(
  _SIMULATORSAMPLESRESPONSE.fields_by_name['header'])
_SIMULATORSAMPLESRESPONSE.fields_by_name['header'].containing_oneof = _SIMULATORSAMPLESRESPONSE.oneofs_by_name['body']
_SIMULATORSAMPLESRESPONSE.oneofs_by_name['body'].fields.append(
  _SIMULATORSAMPLESRESPONSE.fields_by_name['data'])
_SIMULATORSAMPLESRESPONSE.fields_by_name['data'].containing_oneof = _SIMULATORSAMPLESRESPONSE.oneofs_by_name['body']
_ICPRESULTDATA.oneofs_by_name['data'].fields.append(
  _ICPRESULTDATA.fields_by_name['intValue'])
_ICPRESULTDATA.fields_by_name['intValue'].containing_oneof = _ICPRESULTDATA.oneofs_by_name['data']
_ICPRESULTDATA.oneofs_by_name['data'].fields.append(
  _ICPRESULTDATA.fields_by_name['doubleValue'])
_ICPRESULTDATA.fields_by_name['doubleValue'].containing_oneof = _ICPRESULTDATA.oneofs_by_name['data']
_ICPRESULTDATA.oneofs_by_name['data'].fields.append(
  _ICPRESULTDATA.fields_by_name['booleanValue'])
_ICPRESULTDATA.fields_by_name['booleanValue'].containing_oneof = _ICPRESULTDATA.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['GetProgramMetadataRequest'] = _GETPROGRAMMETADATAREQUEST
DESCRIPTOR.message_types_by_name['GetProgramMetadataResponse'] = _GETPROGRAMMETADATARESPONSE
DESCRIPTOR.message_types_by_name['ProgramStreamMetadata'] = _PROGRAMSTREAMMETADATA
DESCRIPTOR.message_types_by_name['StreamMetadata'] = _STREAMMETADATA
DESCRIPTOR.message_types_by_name['StreamMetadataExtractionError'] = _STREAMMETADATAEXTRACTIONERROR
DESCRIPTOR.message_types_by_name['IterationData'] = _ITERATIONDATA
DESCRIPTOR.message_types_by_name['GetJobResultSchemaRequest'] = _GETJOBRESULTSCHEMAREQUEST
DESCRIPTOR.message_types_by_name['GetJobResultSchemaResponse'] = _GETJOBRESULTSCHEMARESPONSE
DESCRIPTOR.message_types_by_name['GetJobStateRequest'] = _GETJOBSTATEREQUEST
DESCRIPTOR.message_types_by_name['GetJobStateResponse'] = _GETJOBSTATERESPONSE
DESCRIPTOR.message_types_by_name['GetJobNamedResultHeaderRequest'] = _GETJOBNAMEDRESULTHEADERREQUEST
DESCRIPTOR.message_types_by_name['GetJobNamedResultHeaderResponse'] = _GETJOBNAMEDRESULTHEADERRESPONSE
DESCRIPTOR.message_types_by_name['GetJobNamedResultRequest'] = _GETJOBNAMEDRESULTREQUEST
DESCRIPTOR.message_types_by_name['GetJobNamedResultResponse'] = _GETJOBNAMEDRESULTRESPONSE
DESCRIPTOR.message_types_by_name['GetJobErrorsRequest'] = _GETJOBERRORSREQUEST
DESCRIPTOR.message_types_by_name['GetJobDebugDataRequest'] = _GETJOBDEBUGDATAREQUEST
DESCRIPTOR.message_types_by_name['GetJobDebugDataResponse'] = _GETJOBDEBUGDATARESPONSE
DESCRIPTOR.message_types_by_name['GetJobErrorsResponse'] = _GETJOBERRORSRESPONSE
DESCRIPTOR.message_types_by_name['PullAnalysedResultsRequest'] = _PULLANALYSEDRESULTSREQUEST
DESCRIPTOR.message_types_by_name['AnalysedResultsResponse'] = _ANALYSEDRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['PullResultOutputRequest'] = _PULLRESULTOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['PullResultOutputResponse'] = _PULLRESULTOUTPUTRESPONSE
DESCRIPTOR.message_types_by_name['BinaryWrapper'] = _BINARYWRAPPER
DESCRIPTOR.message_types_by_name['PullFileResultRequest'] = _PULLFILERESULTREQUEST
DESCRIPTOR.message_types_by_name['FileResultResponse'] = _FILERESULTRESPONSE
DESCRIPTOR.message_types_by_name['PullSimulatorSamplesRequest'] = _PULLSIMULATORSAMPLESREQUEST
DESCRIPTOR.message_types_by_name['SimulatorSamplesResponse'] = _SIMULATORSAMPLESRESPONSE
DESCRIPTOR.message_types_by_name['IcpResultData'] = _ICPRESULTDATA
DESCRIPTOR.message_types_by_name['StreamResultData'] = _STREAMRESULTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetProgramMetadataRequest = _reflection.GeneratedProtocolMessageType('GetProgramMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROGRAMMETADATAREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetProgramMetadataRequest)
  })
_sym_db.RegisterMessage(GetProgramMetadataRequest)

GetProgramMetadataResponse = _reflection.GeneratedProtocolMessageType('GetProgramMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROGRAMMETADATARESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetProgramMetadataResponse)
  })
_sym_db.RegisterMessage(GetProgramMetadataResponse)

ProgramStreamMetadata = _reflection.GeneratedProtocolMessageType('ProgramStreamMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAMSTREAMMETADATA,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.ProgramStreamMetadata)
  })
_sym_db.RegisterMessage(ProgramStreamMetadata)

StreamMetadata = _reflection.GeneratedProtocolMessageType('StreamMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMETADATA,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.StreamMetadata)
  })
_sym_db.RegisterMessage(StreamMetadata)

StreamMetadataExtractionError = _reflection.GeneratedProtocolMessageType('StreamMetadataExtractionError', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMETADATAEXTRACTIONERROR,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.StreamMetadataExtractionError)
  })
_sym_db.RegisterMessage(StreamMetadataExtractionError)

IterationData = _reflection.GeneratedProtocolMessageType('IterationData', (_message.Message,), {

  'ForEachIntIterationValues' : _reflection.GeneratedProtocolMessageType('ForEachIntIterationValues', (_message.Message,), {
    'DESCRIPTOR' : _ITERATIONDATA_FOREACHINTITERATIONVALUES,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.IterationData.ForEachIntIterationValues)
    })
  ,

  'ForIntIterationValues' : _reflection.GeneratedProtocolMessageType('ForIntIterationValues', (_message.Message,), {
    'DESCRIPTOR' : _ITERATIONDATA_FORINTITERATIONVALUES,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.IterationData.ForIntIterationValues)
    })
  ,

  'ForEachDoubleIterationValues' : _reflection.GeneratedProtocolMessageType('ForEachDoubleIterationValues', (_message.Message,), {
    'DESCRIPTOR' : _ITERATIONDATA_FOREACHDOUBLEITERATIONVALUES,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.IterationData.ForEachDoubleIterationValues)
    })
  ,

  'ForDoubleIterationValues' : _reflection.GeneratedProtocolMessageType('ForDoubleIterationValues', (_message.Message,), {
    'DESCRIPTOR' : _ITERATIONDATA_FORDOUBLEITERATIONVALUES,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.IterationData.ForDoubleIterationValues)
    })
  ,
  'DESCRIPTOR' : _ITERATIONDATA,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.IterationData)
  })
_sym_db.RegisterMessage(IterationData)
_sym_db.RegisterMessage(IterationData.ForEachIntIterationValues)
_sym_db.RegisterMessage(IterationData.ForIntIterationValues)
_sym_db.RegisterMessage(IterationData.ForEachDoubleIterationValues)
_sym_db.RegisterMessage(IterationData.ForDoubleIterationValues)

GetJobResultSchemaRequest = _reflection.GeneratedProtocolMessageType('GetJobResultSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBRESULTSCHEMAREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobResultSchemaRequest)
  })
_sym_db.RegisterMessage(GetJobResultSchemaRequest)

GetJobResultSchemaResponse = _reflection.GeneratedProtocolMessageType('GetJobResultSchemaResponse', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _GETJOBRESULTSCHEMARESPONSE_ITEM,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobResultSchemaResponse.Item)
    })
  ,
  'DESCRIPTOR' : _GETJOBRESULTSCHEMARESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobResultSchemaResponse)
  })
_sym_db.RegisterMessage(GetJobResultSchemaResponse)
_sym_db.RegisterMessage(GetJobResultSchemaResponse.Item)

GetJobStateRequest = _reflection.GeneratedProtocolMessageType('GetJobStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSTATEREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobStateRequest)
  })
_sym_db.RegisterMessage(GetJobStateRequest)

GetJobStateResponse = _reflection.GeneratedProtocolMessageType('GetJobStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSTATERESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobStateResponse)
  })
_sym_db.RegisterMessage(GetJobStateResponse)

GetJobNamedResultHeaderRequest = _reflection.GeneratedProtocolMessageType('GetJobNamedResultHeaderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBNAMEDRESULTHEADERREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobNamedResultHeaderRequest)
  })
_sym_db.RegisterMessage(GetJobNamedResultHeaderRequest)

GetJobNamedResultHeaderResponse = _reflection.GeneratedProtocolMessageType('GetJobNamedResultHeaderResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBNAMEDRESULTHEADERRESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobNamedResultHeaderResponse)
  })
_sym_db.RegisterMessage(GetJobNamedResultHeaderResponse)

GetJobNamedResultRequest = _reflection.GeneratedProtocolMessageType('GetJobNamedResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBNAMEDRESULTREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobNamedResultRequest)
  })
_sym_db.RegisterMessage(GetJobNamedResultRequest)

GetJobNamedResultResponse = _reflection.GeneratedProtocolMessageType('GetJobNamedResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBNAMEDRESULTRESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobNamedResultResponse)
  })
_sym_db.RegisterMessage(GetJobNamedResultResponse)

GetJobErrorsRequest = _reflection.GeneratedProtocolMessageType('GetJobErrorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBERRORSREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobErrorsRequest)
  })
_sym_db.RegisterMessage(GetJobErrorsRequest)

GetJobDebugDataRequest = _reflection.GeneratedProtocolMessageType('GetJobDebugDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBDEBUGDATAREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobDebugDataRequest)
  })
_sym_db.RegisterMessage(GetJobDebugDataRequest)

GetJobDebugDataResponse = _reflection.GeneratedProtocolMessageType('GetJobDebugDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBDEBUGDATARESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobDebugDataResponse)
  })
_sym_db.RegisterMessage(GetJobDebugDataResponse)

GetJobErrorsResponse = _reflection.GeneratedProtocolMessageType('GetJobErrorsResponse', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR' : _GETJOBERRORSRESPONSE_ERROR,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobErrorsResponse.Error)
    })
  ,
  'DESCRIPTOR' : _GETJOBERRORSRESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.GetJobErrorsResponse)
  })
_sym_db.RegisterMessage(GetJobErrorsResponse)
_sym_db.RegisterMessage(GetJobErrorsResponse.Error)

PullAnalysedResultsRequest = _reflection.GeneratedProtocolMessageType('PullAnalysedResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PULLANALYSEDRESULTSREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullAnalysedResultsRequest)
  })
_sym_db.RegisterMessage(PullAnalysedResultsRequest)

AnalysedResultsResponse = _reflection.GeneratedProtocolMessageType('AnalysedResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSEDRESULTSRESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.AnalysedResultsResponse)
  })
_sym_db.RegisterMessage(AnalysedResultsResponse)

PullResultOutputRequest = _reflection.GeneratedProtocolMessageType('PullResultOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _PULLRESULTOUTPUTREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullResultOutputRequest)
  })
_sym_db.RegisterMessage(PullResultOutputRequest)

PullResultOutputResponse = _reflection.GeneratedProtocolMessageType('PullResultOutputResponse', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _PULLRESULTOUTPUTRESPONSE_HEADER,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullResultOutputResponse.Header)
    })
  ,

  'Data' : _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {
    'DESCRIPTOR' : _PULLRESULTOUTPUTRESPONSE_DATA,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullResultOutputResponse.Data)
    })
  ,

  'Npz' : _reflection.GeneratedProtocolMessageType('Npz', (_message.Message,), {
    'DESCRIPTOR' : _PULLRESULTOUTPUTRESPONSE_NPZ,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullResultOutputResponse.Npz)
    })
  ,

  'Npy' : _reflection.GeneratedProtocolMessageType('Npy', (_message.Message,), {
    'DESCRIPTOR' : _PULLRESULTOUTPUTRESPONSE_NPY,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullResultOutputResponse.Npy)
    })
  ,
  'DESCRIPTOR' : _PULLRESULTOUTPUTRESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullResultOutputResponse)
  })
_sym_db.RegisterMessage(PullResultOutputResponse)
_sym_db.RegisterMessage(PullResultOutputResponse.Header)
_sym_db.RegisterMessage(PullResultOutputResponse.Data)
_sym_db.RegisterMessage(PullResultOutputResponse.Npz)
_sym_db.RegisterMessage(PullResultOutputResponse.Npy)

BinaryWrapper = _reflection.GeneratedProtocolMessageType('BinaryWrapper', (_message.Message,), {
  'DESCRIPTOR' : _BINARYWRAPPER,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.BinaryWrapper)
  })
_sym_db.RegisterMessage(BinaryWrapper)

PullFileResultRequest = _reflection.GeneratedProtocolMessageType('PullFileResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _PULLFILERESULTREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullFileResultRequest)
  })
_sym_db.RegisterMessage(PullFileResultRequest)

FileResultResponse = _reflection.GeneratedProtocolMessageType('FileResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILERESULTRESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.FileResultResponse)
  })
_sym_db.RegisterMessage(FileResultResponse)

PullSimulatorSamplesRequest = _reflection.GeneratedProtocolMessageType('PullSimulatorSamplesRequest', (_message.Message,), {
  'DESCRIPTOR' : _PULLSIMULATORSAMPLESREQUEST,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.PullSimulatorSamplesRequest)
  })
_sym_db.RegisterMessage(PullSimulatorSamplesRequest)

SimulatorSamplesResponse = _reflection.GeneratedProtocolMessageType('SimulatorSamplesResponse', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _SIMULATORSAMPLESRESPONSE_HEADER,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.SimulatorSamplesResponse.Header)
    })
  ,

  'Data' : _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {
    'DESCRIPTOR' : _SIMULATORSAMPLESRESPONSE_DATA,
    '__module__' : 'qm.pb.job_results_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.SimulatorSamplesResponse.Data)
    })
  ,
  'DESCRIPTOR' : _SIMULATORSAMPLESRESPONSE,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.SimulatorSamplesResponse)
  })
_sym_db.RegisterMessage(SimulatorSamplesResponse)
_sym_db.RegisterMessage(SimulatorSamplesResponse.Header)
_sym_db.RegisterMessage(SimulatorSamplesResponse.Data)

IcpResultData = _reflection.GeneratedProtocolMessageType('IcpResultData', (_message.Message,), {
  'DESCRIPTOR' : _ICPRESULTDATA,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.IcpResultData)
  })
_sym_db.RegisterMessage(IcpResultData)

StreamResultData = _reflection.GeneratedProtocolMessageType('StreamResultData', (_message.Message,), {
  'DESCRIPTOR' : _STREAMRESULTDATA,
  '__module__' : 'qm.pb.job_results_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.results_analyser.StreamResultData)
  })
_sym_db.RegisterMessage(StreamResultData)


DESCRIPTOR._options = None
_GETJOBNAMEDRESULTHEADERRESPONSE.fields_by_name['done']._options = None
_GETJOBNAMEDRESULTHEADERRESPONSE.fields_by_name['closed']._options = None
_GETJOBNAMEDRESULTREQUEST.fields_by_name['offset']._options = None

_JOBRESULTSSERVICE = _descriptor.ServiceDescriptor(
  name='JobResultsService',
  full_name='qm.grpc.results_analyser.JobResultsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4739,
  serialized_end=5647,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetJobResultSchema',
    full_name='qm.grpc.results_analyser.JobResultsService.GetJobResultSchema',
    index=0,
    containing_service=None,
    input_type=_GETJOBRESULTSCHEMAREQUEST,
    output_type=_GETJOBRESULTSCHEMARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobState',
    full_name='qm.grpc.results_analyser.JobResultsService.GetJobState',
    index=1,
    containing_service=None,
    input_type=_GETJOBSTATEREQUEST,
    output_type=_GETJOBSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobNamedResultHeader',
    full_name='qm.grpc.results_analyser.JobResultsService.GetJobNamedResultHeader',
    index=2,
    containing_service=None,
    input_type=_GETJOBNAMEDRESULTHEADERREQUEST,
    output_type=_GETJOBNAMEDRESULTHEADERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobNamedResult',
    full_name='qm.grpc.results_analyser.JobResultsService.GetJobNamedResult',
    index=3,
    containing_service=None,
    input_type=_GETJOBNAMEDRESULTREQUEST,
    output_type=_GETJOBNAMEDRESULTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobDebugData',
    full_name='qm.grpc.results_analyser.JobResultsService.GetJobDebugData',
    index=4,
    containing_service=None,
    input_type=_GETJOBDEBUGDATAREQUEST,
    output_type=_GETJOBDEBUGDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobErrors',
    full_name='qm.grpc.results_analyser.JobResultsService.GetJobErrors',
    index=5,
    containing_service=None,
    input_type=_GETJOBERRORSREQUEST,
    output_type=_GETJOBERRORSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProgramMetadata',
    full_name='qm.grpc.results_analyser.JobResultsService.GetProgramMetadata',
    index=6,
    containing_service=None,
    input_type=_GETPROGRAMMETADATAREQUEST,
    output_type=_GETPROGRAMMETADATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBRESULTSSERVICE)

DESCRIPTOR.services_by_name['JobResultsService'] = _JOBRESULTSSERVICE

# @@protoc_insertion_point(module_scope)
